
from rule_001 import rule_001
from rule_002 import rule_002
from rule_003 import rule_003
from rule_004 import rule_004
from rule_005 import rule_005
from rule_006 import rule_006
from rule_007 import rule_007
from rule_008 import rule_008
from rule_009 import rule_009
from rule_010 import rule_010
from rule_011 import rule_011
from rule_012 import rule_012
from rule_013 import rule_013
from rule_014 import rule_014
from rule_015 import rule_015

#  ordering rules to handle compressed if statements
from rule_020 import rule_020  # end if
from rule_021 import rule_021  # else
from rule_022 import rule_022  # code after else
from rule_023 import rule_023  # elsif
from rule_024 import rule_024  # code after then

from rule_025 import rule_025
from rule_026 import rule_026
from rule_027 import rule_027
from rule_028 import rule_028
from rule_029 import rule_029
